# PDB2PQR Server

Currently using PDB2PQR Version master

Return to the PDB2PQR homepage.

This server enables a user to convert PDB files into PQR files. PQR files are PDB files where the occupancy and B-factor columns have been replaced by per-atom charge and radius.

pKa calculations are performed by PROPKA.

For more information on PDB2PQR please see the:

- Home Page
- Register (and help support PDB2PQR & APBS)
- User Guide
- Examples
- Release Notes

If you use the PDB2PQR service in a publication, please cite:

> Dolinsky TJ, Nielsen JE, McCammon JA, Baker NA. PDB2PQR: an automated pipeline for the setup, execution, and analysis of Poisson-Boltzmann electrostatics calculations. Nucleic Acids Research 32 W665-W667 (2004). [Link]

Note: This server uses automatic refreshing to update the status of your PDB2PQR submission.

Please enter either:

> a PDB ID:
> upload a PDB file:

Pick a forcefield to use:

> AMBER
> CHARMM
> PARSE
> PEOEPB
> SWANSON
> TYL06
> User-defined forcefield (help):
> User-defined names (help):
> * If you select user-defined forcefield, you also need to specify a user-defined .names file.

Pick an output naming scheme to use (help):

> Internal naming scheme (What's this?)
> AMBER
> CHARMM
> PARSE
> PEOEPB
> SWANSON
> TYL06

Available options:

> Ensure that new atoms are not rebuilt too close to existing atoms
> Optimize the hydrogen bonding network
> Assign charges to the ligand specified in a MOL2 file:
> Create an APBS input file (this also enables the option to run APBS and visualize your results through the web interface, if it has been installed)
> Add/keep chain IDs in the PQR file
> Insert whitespaces between atom name and residue name, between x and y, and between y and z
> Create Typemap output
> Make the protein's N-terminus neutral (requires PARSE forcefield)
> Make the protein's C-terminus neutral (requires PARSE forcefield)
> Remove the waters from the output file

pKa Options*:

> Use pH
> No pKa calculation
> Use PROPKA to assign protonation states at provided pH
> Use PDB2PKA to parametrize ligands and assign pKa values (requires PARSE forcefield) at provided pH
> * Warning: PDB2PKA is currently experimental and the process can take a very long time. See the Release Notes for changes since the last version.

The PDB2PQR application and web server was written by:

> Jens Erik Nielsen
> Todd Dolinsky
> Nathan Baker
> Kyle Monson

PDB2PQR Opal integration by:

> Wes Goodman
> Samir Unni
> Yong Huang

3dMol visualization provided by:

> David Koes

JMol visualization scripts and applets provided by:

> Robert Hanson

PDB2PQR is supported by NIH grant GM069702-01 to NAB, the NPACI Alpha Project program, and the National Biomedical Computation Resource.

Before sending a bug report you may want to check the pdb2pqr-users mailing list archives to make sure your question has not already been addressed.

For additional support, feature requests, and bug reports you may contact the pdb2pqr-users mailing list.